@@ -132,6 +132,8 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 5.0",
     "Framework :: Django :: 5.1",
     "Framework :: Django :: 5.2",
+    "Framework :: Django :: 6",
+    "Framework :: Django :: 6.0",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -151,6 +153,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Hypothesis",
     "Framework :: IDLE",
     "Framework :: IPython",
+    "Framework :: InvenTree",
     "Framework :: Jupyter",
     "Framework :: Jupyter :: JupyterLab",
     "Framework :: Jupyter :: JupyterLab :: 1",
@@ -558,6 +561,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Visual Basic",
     "Programming Language :: XBasic",
     "Programming Language :: YACC",
+    "Programming Language :: Zig",
     "Programming Language :: Zope",
     "Topic :: Adaptive Technologies",
     "Topic :: Artistic Software",
